@@ -321,68 +321,15 @@ class DB2Compiler(compiler.SQLCompiler):
 
     def limit_clause(self, select):
         if (select._limit is not None) and (select._offset is None):
-            return " FETCH FIRST %s ROWS ONLY" % select._limit
+            return " FETCH FIRST {} ROWS ONLY".format(select._limit)
         else:
-            return ""
-        
-    def visit_select(self, select, **kwargs):
-        limit, offset = select._limit, select._offset
-        sql_ori = compiler.SQLCompiler.visit_select(self, select, **kwargs)
-        if offset is not None:
-            __rownum = 'Z.__ROWNUM'
-            sql_split = re.split("[\s+]FROM ", sql_ori, 1)
-            sql_sec = ""
-            sql_sec = " \nFROM %s " % ( sql_split[1] )
-                
-            dummyVal = "Z.__db2_"
-            sql_pri = ""
-            
-            sql_sel = "SELECT "
-            if select._distinct:
-                sql_sel = "SELECT DISTINCT "
+            text = ""
+            if select._limit is not None:
+                text += ' LIMIT {}'.format(select._limit)
+            if select._offset is not None:
+                text += ' OFFSET {}'.format(select._offset)
+            return text
 
-            sql_select_token = sql_split[0].split( "," )
-            i = 0
-            while ( i < len( sql_select_token ) ):
-                if sql_select_token[i].count( "TIMESTAMP(DATE(SUBSTR(CHAR(" ) == 1:
-                    sql_sel = "%s \"%s%d\"," % ( sql_sel, dummyVal, i + 1 )
-                    sql_pri = '%s %s,%s,%s,%s AS "%s%d",' % ( 
-                                    sql_pri,
-                                    sql_select_token[i],
-                                    sql_select_token[i + 1],
-                                    sql_select_token[i + 2],
-                                    sql_select_token[i + 3],
-                                    dummyVal, i + 1 )
-                    i = i + 4
-                    continue
-                
-                if sql_select_token[i].count( " AS " ) == 1:
-                    temp_col_alias = sql_select_token[i].split( " AS " )
-                    sql_pri = '%s %s,' % ( sql_pri, sql_select_token[i] )
-                    sql_sel = "%s %s," % ( sql_sel, temp_col_alias[1] )
-                    i = i + 1
-                    continue
-            
-                sql_pri = '%s %s AS "%s%d",' % ( sql_pri, sql_select_token[i], dummyVal, i + 1 )
-                sql_sel = "%s \"%s%d\"," % ( sql_sel, dummyVal, i + 1 )
-                i = i + 1
-
-            sql_pri = sql_pri[:len( sql_pri ) - 1]
-            sql_pri = "%s%s" % ( sql_pri, sql_sec )
-            sql_sel = sql_sel[:len( sql_sel ) - 1]
-            sql = '%s, ( ROW_NUMBER() OVER() ) AS "%s" FROM ( %s ) AS M' % ( sql_sel, __rownum, sql_pri )
-            sql = '%s FROM ( %s ) Z WHERE' % ( sql_sel, sql )
-            
-            if offset is not 0:
-                sql = '%s "%s" > %d' % ( sql, __rownum, offset )
-            if offset is not 0 and limit is not None:
-                sql = '%s AND ' % ( sql )
-            if limit is not None:
-                sql = '%s "%s" <= %d' % ( sql, __rownum, offset + limit )
-            return "( %s )" % ( sql, )
-        else:
-            return sql_ori
-    
     def visit_sequence(self, sequence):
         return "NEXT VALUE FOR %s" % sequence.name
 
